#!/bin/bash

#Copyright (C) 2013 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or 
#Modify it under the terms of the GNU General Public License 
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful, 
#but WITHOUT ANY WARRANTY; without even the implied warranty of 
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
#GNU General Public License for more details

INSTALLER_LANG="JP"

SCRIPT_DIR=$(cd $(dirname $0);pwd)

#DATA_SCRIPT="${SCRIPT_DIR}/scripts/cloud_data_maint_JP.sh INSERT"
DATA_SCRIPT="${SCRIPT_DIR}/scripts/aws_option_install_data_JP.sql"
. ${SCRIPT_DIR}/scripts/cloud_option_install_main.sh